@@ -1,18 +1,19 @@
+#[macro_use]
+extern crate tracing;
+
 mod common;
 
-use common::VaultServerHelper;
+use common::{VaultServer, VaultServerHelper};
+use test_env_log::test;
 use vaultrs::auth::approle;
 use vaultrs::client::Client;
 use vaultrs::error::ClientError;
-use vaultrs_test::docker::{Server, ServerConfig};
-use vaultrs_test::{VaultServer, VaultServerConfig};
 
 #[test]
 fn test() {
-    let config = VaultServerConfig::default(Some(common::VERSION));
-    let instance = config.to_instance();
-    instance.run(|ops| async move {
-        let server = VaultServer::new(&ops, &config);
+    let test = common::new_test();
+    test.run(|instance| async move {
+        let server: VaultServer = instance.server();
         let client = server.client();
         let endpoint = setup(&server, &client).await.unwrap();
 
@@ -219,6 +220,7 @@ pub struct AppRoleEndpoint {
 }
 
 async fn setup(server: &VaultServer, client: &impl Client) -> Result<AppRoleEndpoint, ClientError> {
+    debug!("setting up AppRole auth engine");
     let path = "approle_test";
     let role_name = "test";
 
