@@ -1,18 +1,18 @@
+#[macro_use]
+extern crate tracing;
+
 mod common;
 
-use common::VaultServerHelper;
+use common::{VaultServer, VaultServerHelper};
+use test_env_log::test;
 use vaultrs::client::Client;
 use vaultrs::{api::ssh::requests::SetRoleRequest, error::ClientError};
-use vaultrs_test::docker::{Server, ServerConfig};
-use vaultrs_test::{VaultServer, VaultServerConfig};
 
 #[test]
 fn test() {
-    let config = VaultServerConfig::default(Some(common::VERSION));
-    let instance = config.to_instance();
-
-    instance.run(|ops| async move {
-        let server = VaultServer::new(&ops, &config);
+    let test = common::new_test();
+    test.run(|instance| async move {
+        let server: VaultServer = instance.server();
         let client = server.client();
         let endpoint = setup(&server, &client).await.unwrap();
 
@@ -217,12 +217,14 @@ pub struct SSHEndpoint {
 }
 
 async fn setup(server: &VaultServer, client: &impl Client) -> Result<SSHEndpoint, ClientError> {
+    debug!("setting up SSH auth engine");
+
     let path = "ssh_test";
     let role = "test";
     let dyn_role = "test_dyn";
     let otp_role = "test_otp";
 
-    // Mount the OIDC auth engine
+    // Mount the SSH auth engine
     server.mount_secret(client, path, "ssh").await?;
 
     // Create key
