@@ -1,17 +1,18 @@
+#[macro_use]
+extern crate tracing;
+
 mod common;
 
-use common::VaultServerHelper;
+use common::{VaultServer, VaultServerHelper};
+use test_env_log::test;
 use vaultrs::client::Client;
 use vaultrs::{api::token::requests::CreateTokenRequest, error::ClientError, token};
-use vaultrs_test::docker::{Server, ServerConfig};
-use vaultrs_test::{VaultServer, VaultServerConfig};
 
 #[test]
 fn test() {
-    let config = VaultServerConfig::default(Some(common::VERSION));
-    let instance = config.to_instance();
-    instance.run(|ops| async move {
-        let server = VaultServer::new(&ops, &config);
+    let test = common::new_test();
+    test.run(|instance| async move {
+        let server: VaultServer = instance.server();
         let client = server.client();
         let mut token = setup(&client).await.unwrap();
 
@@ -161,6 +162,8 @@ struct Token {
 }
 
 async fn setup(client: &impl Client) -> Result<Token, ClientError> {
+    debug!("creating new token");
+
     // Create a new token
     let resp = token::new(
         client,
