@@ -1,18 +1,19 @@
+#[macro_use]
+extern crate tracing;
+
 mod common;
 
-use common::VaultServerHelper;
+use common::{VaultServer, VaultServerHelper};
+use test_env_log::test;
 use vaultrs::auth::userpass;
 use vaultrs::client::Client;
 use vaultrs::error::ClientError;
-use vaultrs_test::docker::{Server, ServerConfig};
-use vaultrs_test::{VaultServer, VaultServerConfig};
 
 #[test]
 fn test() {
-    let config = VaultServerConfig::default(Some(common::VERSION));
-    let instance = config.to_instance();
-    instance.run(|ops| async move {
-        let server = VaultServer::new(&ops, &config);
+    let test = common::new_test();
+    test.run(|instance| async move {
+        let server: VaultServer = instance.server();
         let client = server.client();
         let endpoint = setup(&server, &client).await.unwrap();
 
@@ -107,6 +108,8 @@ async fn setup(
     server: &VaultServer,
     client: &impl Client,
 ) -> Result<UserPassEndpoint, ClientError> {
+    debug!("setting up UserPass auth engine");
+
     let path = "userpass_test";
     let username = "test";
     let password = "This1sAT3st!";
